@@ -1,14 +1,12 @@
 import numpy as np
 
 
-def chebyshev_steps(
-    small_m: float, big_m: float, num_epochs: int
-) -> np.ndarray:
+def chebyshev_steps(small_m: float, big_m: float, num_epochs: int) -> np.ndarray:
     """
     :param small_m: float. stands for 'm' notation.
     :param big_m:  float. stands for 'M' notation.
     :param num_epochs: int. stands for 'T' notation.
-    :return:
+    :return: np.array. chebyshev_steps
     """
     c, r = (big_m + small_m) / 2.0, (big_m - small_m) / 2.0
     thetas = (np.arange(num_epochs) + 0.5) / num_epochs * np.pi
@@ -25,8 +23,8 @@ def chebyshev_perm(num_epochs: int) -> np.ndarray:
 def get_chebyshev_schedule(num_epochs: int) -> np.ndarray:
     num_epochs: int = num_epochs - 2
 
-    steps = chebyshev_steps(0.1, 1, num_epochs)
-    perm = chebyshev_perm(num_epochs)
+    steps: np.ndarray = chebyshev_steps(0.1, 1, num_epochs)
+    perm: np.ndarray = chebyshev_perm(num_epochs)
     chebyshev_schedule = steps[perm]
 
     return chebyshev_schedule
